# LangChain TypeScript Reference Documentation

This directory contains the source code and build process for the TypeScript reference documentation site, hosted at [`reference.langchain.com/javascript`](https://reference.langchain.com/javascript). This site serves references for LangChain, LangGraph, LangSmith, and LangChain integration packages (such as [`@langchain/anthropic`](https://npm.com/package/@langchain/anthropic), [`@langchain/openai`](https://npm.com/package/@langchain/openai), etc.).
